# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: product.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'product.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rproduct.proto\x12\x07product\"\'\n\x11GetProductRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"O\n\x13ListProductsRequest\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\"p\n\x0fProductResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\x01\x12\x10\n\x08\x63\x61tegory\x18\x05 \x01(\t\x12\r\n\x05stock\x18\x06 \x01(\x05\"k\n\x14ListProductsResponse\x12*\n\x08products\x18\x01 \x03(\x0b\x32\x18.product.ProductResponse\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x12\n\npage_count\x18\x03 \x01(\x05\x32\x9a\x01\n\x07Product\x12\x42\n\nGetProduct\x12\x1a.product.GetProductRequest\x1a\x18.product.ProductResponse\x12K\n\x0cListProducts\x12\x1c.product.ListProductsRequest\x1a\x1d.product.ListProductsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'product_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETPRODUCTREQUEST']._serialized_start=26
  _globals['_GETPRODUCTREQUEST']._serialized_end=65
  _globals['_LISTPRODUCTSREQUEST']._serialized_start=67
  _globals['_LISTPRODUCTSREQUEST']._serialized_end=146
  _globals['_PRODUCTRESPONSE']._serialized_start=148
  _globals['_PRODUCTRESPONSE']._serialized_end=260
  _globals['_LISTPRODUCTSRESPONSE']._serialized_start=262
  _globals['_LISTPRODUCTSRESPONSE']._serialized_end=369
  _globals['_PRODUCT']._serialized_start=372
  _globals['_PRODUCT']._serialized_end=526
# @@protoc_insertion_point(module_scope)
