# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x04user\"\"\n\x03Tag\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"z\n\x08UserData\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x12\n\nvisibility\x18\x05 \x01(\t\x12\x17\n\x04tags\x18\x06 \x03(\x0b\x32\t.user.Tag\",\n\x18GetUserByUsernameRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"/\n\x0fGetUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.user.UserData2T\n\x04User\x12L\n\x11GetUserByUsername\x12\x1e.user.GetUserByUsernameRequest\x1a\x15.user.GetUserResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TAG']._serialized_start=20
  _globals['_TAG']._serialized_end=54
  _globals['_USERDATA']._serialized_start=56
  _globals['_USERDATA']._serialized_end=178
  _globals['_GETUSERBYUSERNAMEREQUEST']._serialized_start=180
  _globals['_GETUSERBYUSERNAMEREQUEST']._serialized_end=224
  _globals['_GETUSERRESPONSE']._serialized_start=226
  _globals['_GETUSERRESPONSE']._serialized_end=273
  _globals['_USER']._serialized_start=275
  _globals['_USER']._serialized_end=359
# @@protoc_insertion_point(module_scope)
